# group settings for 'ws' (OPAL)
# https://its.cern.ch/jira/browse/NOAFS-501
# based on /afs/cern.ch/group/ws/group_env.csh
# modified for migration to cvmfs

setenv OPAL /cvmfs/opal.cern.ch     ##Define the top of the OPAL project tree
# In cvmfs we don't have the same structure as we did in AFS...
                                    ##OPAL generator tree
setenv otop "$OPAL"         ##Define the top of the OPAL code tree
setenv opal "$OPAL"         ##Define the top of the OPAL project tree

## Generate OPAL symbols <version_xx>
setenv version_opal pro
if ( -f "${otop}/utl/oversion.${version_opal}.csh" ) then
        hpx_source "${otop}/utl/oversion.${version_opal}.csh"
else
        echo "Warning: oversion.${version_opal}.csh does not exist!"
endif

setenv OPAL_P_DB "${otop}/db"
setenv cern /cvmfs/opal.cern.ch/cern
setenv libver "pro"
setenv gksver "pro"

# set the hardware variable, needed for some scripts (ytofort, fort, link, ...)
setenv HARDWARE `"${opal}/scripts/hardware"`
# 
if ( $HARDWARE == "i386slc3" ) then
    set OpalBinTag = '/i386slc3'
else if ( $HARDWARE == "i386slc5" ) then
    set OpalBinTag = '/i386slc5'
else if ( $HARDWARE == "amd64slc5" ) then
    set OpalBinTag = '/amd64slc5'
else if ( $HARDWARE == "i386slc6" || $HARDWARE == "amd64slc6" ) then
    set OpalBinTag = '/i386slc6'
    setenv PATH "${PATH}:${cern}${OpalBinTag}/${libver}/bin"
else if ( $HARDWARE == "i386cc7" || $HARDWARE == "amd64cc7" ) then
    set OpalBinTag = '/i386cc7'
    setenv PATH "${PATH}:${cern}${OpalBinTag}/${libver}/bin"
else if ( $HARDWARE == "i386cc8" || $HARDWARE == "amd64cc8" ) then
    set OpalBinTag = '/i386cc8'
    setenv PATH "${PATH}:${cern}${OpalBinTag}/${libver}/bin"
else
    set OpalBinTag = ''
endif

## Define CERN global variables (wrong as of SLC5, does anybody care?????)
setenv cern_root "${cern}${OpalBinTag}/${libver}"
setenv kernlib "${cern_root}/lib/libkernlib.a"
setenv packlib "${cern_root}/lib/libpacklib.a"
setenv mathlib "${cern_root}/lib/libmathlib.a"
setenv graflib "${cern_root}/lib/libgraflib.a"
setenv graflibX11 "${cern_root}/lib/libgrafX11.a"
# the link script uses $CERN
setenv CERN "${cern}${OpalBinTag}"

setenv PATH "${HOME}/scripts:${otop}/pro${OpalBinTag}/bin:${opal}/scripts:${cern_root}/bin:${PATH}"


# used by whicho and thus all tool wrappers:
setenv propath ". ${HOME}/car ${HOME}/cra ${HOME}${OpalBinTag}/lib ${HOME}${OpalBinTag}/src ${otop}/pro/src/car ${otop}/pro/src/cra ${otop}/pro${OpalBinTag}/lib"


#
setenv allrope "rope dc cv cj jc cz ct cx ce id lm tb pb eb pe ee em hb hp mb me mm fd od ou tr oc dd px su op si cs dx ll cu"
setenv dstrope "rope dc px ou tr oc od cx su ll cu"
